@@ -916,7 +916,7 @@ print_version_action (GPParams __unused__ *p)
 		  "\n"
 		  "This version of gphoto2 is using the following software versions and options:\n"),
 		VERSION,
-		2016, /* year of release! */
+		2017, /* year of release! */
 		port_message
 		);
 
@@ -948,22 +948,27 @@ _action_camera_capture_preview (GPParams *p, int viewasciiart)
 {
 	CameraFile *file;
 	int	r, fd;
-        char    tmpname[20], *tmpfilename;
-
-	strcpy (tmpname, "tmpfileXXXXXX");
-	fd = mkstemp(tmpname);
-	if (fd == -1) {
-		CR (gp_file_new (&file));
-		tmpfilename = NULL;
+	char tmpname[20], *tmpfilename = NULL;
+	
+	if (p->flags & FLAGS_STDOUT) {
+		fd = dup(fileno(stdout));
 	} else {
-		r = gp_file_new_from_fd (&file, fd);
-		if (r < GP_OK) {
-			close (fd);
-			unlink (tmpname);
-			return r;
+		strcpy (tmpname, "tmpfileXXXXXX");
+		fd = mkstemp(tmpname);
+		if (fd == -1) {
+			CR (gp_file_new (&file));
+			tmpfilename = NULL;
+		} else {
+			r = gp_file_new_from_fd (&file, fd);
+			if (r < GP_OK) {
+				close (fd);
+				unlink (tmpname);
+				return r;
+			}
+			tmpfilename = tmpname;
 		}
-		tmpfilename = tmpname;
 	}
+	CR (gp_file_new_from_fd (&file, fd));
 
 #ifdef HAVE_AA
 	if (viewasciiart)
@@ -971,21 +976,24 @@ _action_camera_capture_preview (GPParams *p, int viewasciiart)
 	else
 #endif
 		r = gp_camera_capture_preview (p->camera, file, p->context);
-
+	fflush(stdout);
 	if (r < 0) {
-		gp_file_unref (file);
+		if(!(p->flags & FLAGS_STDOUT))
+			gp_file_unref (file);
 		unlink (tmpname);
-		return (r);
+		return r;
 	}
 
 	/* name it file_%filename if --filename is set, otherwise capture_preview */
-	r = save_camera_file_to_file (NULL, "capture_preview", p->filename?GP_FILE_TYPE_PREVIEW:GP_FILE_TYPE_NORMAL, file, tmpfilename);
-	gp_file_unref (file);
-	if (r < 0) {
-		unlink (tmpname);
-		return (r);
+	if(!(p->flags & FLAGS_STDOUT)) {
+		r = save_camera_file_to_file (NULL, "capture_preview", p->filename?GP_FILE_TYPE_PREVIEW:GP_FILE_TYPE_NORMAL, file, tmpfilename);
+		gp_file_unref (file);
+		if (r < 0) {
+			unlink (tmpname);
+			return (r);
+		}
 	}
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -1011,7 +1019,7 @@ action_camera_capture_movie (GPParams *p, const char *arg)
 	int		frames,captured_frames=0;
 	char		*xname;
 	struct timeval	starttime;
-
+	
 	if (p->flags & FLAGS_STDOUT) {
 		fd = dup(fileno(stdout));
 		xname = "stdout";
@@ -1339,6 +1347,9 @@ print_storage_info (GPParams *p)
 		if (sinfos[i].fields & GP_STORAGEINFO_FREESPACEIMAGES)
 			printf ("freeimages=%lu\n", (unsigned long)sinfos[i].freeimages);
 	}
+	if (sinfos)
+		free(sinfos);
+
 	return GP_OK;
 }
 
@@ -1616,7 +1627,7 @@ static int
 print_widget (GPParams *p, const char *name, CameraWidget *widget) {
 	const char *label;
 	CameraWidgetType	type;
-	int ret;
+	int ret, readonly;
 
 	ret = gp_widget_get_type (widget, &type);
 	if (ret != GP_OK)
@@ -1624,8 +1635,13 @@ print_widget (GPParams *p, const char *name, CameraWidget *widget) {
 	ret = gp_widget_get_label (widget, &label);
 	if (ret != GP_OK)
 		return ret;
+		
+	ret = gp_widget_get_readonly (widget, &readonly);
+	if (ret != GP_OK)
+		return ret;
 
 	printf ("Label: %s\n", label); /* "Label:" is not i18ned, the "label" variable is */
+	printf ("Readonly: %d\n", readonly);
 	switch (type) {
 	case GP_WIDGET_TEXT: {		/* char *		*/
 		char *txt;
@@ -1718,6 +1734,8 @@ print_widget (GPParams *p, const char *name, CameraWidget *widget) {
 	case GP_WIDGET_BUTTON:
 		break;
 	}
+	
+	printf ("END\n");
 	return GP_OK;
 }
 
@@ -2063,8 +2081,10 @@ set_config_value_action (GPParams *p, const char *name, const char *value) {
 		int	t = -1;
 		struct tm xtm;
 
+		if (!strcasecmp (value, "now")  || !strcasecmp (value, _("now")))
+			t = time(NULL);
 #ifdef HAVE_STRPTIME
-		if (strptime (value, "%c", &xtm) || strptime (value, "%Ec", &xtm))
+		else if (strptime (value, "%c", &xtm) || strptime (value, "%Ec", &xtm))
 			t = mktime (&xtm);
 #endif
 		if (t == -1) {
