@@ -19,6 +19,9 @@
  */
 
 #include "config.h"
+#if defined (HAVE_SIGNAL_H)
+#include <signal.h>
+#endif
 #include "actions.h"
 #include "foreach.h"
 #include <gphoto2/gphoto2-port-info-list.h>
@@ -1543,7 +1546,6 @@ cb_arg_init (poptContext __unused__ ctx,
 	case ARG_VERSION:
 		params->p.r = print_version_action (&gp_params);
 		break;
-
 	default:
 		break;
 	}
@@ -2065,8 +2067,6 @@ main (int argc, char **argv, char **envp)
 		 ARG_CAPTURE_SOUND, N_("Capture an audio clip"), NULL},
 		{"capture-tethered", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, NULL,
 		 ARG_CAPTURE_TETHERED, N_("Wait for shutter release on the camera and download"), N_("COUNT, SECONDS, MILLISECONDS or MATCHSTRING")},
-		{"trigger-capture", '\0', POPT_ARG_NONE, NULL,
-		 ARG_TRIGGER_CAPTURE, N_("Trigger image capture"), NULL},
 		POPT_TABLEEND
 	};
 	const struct poptOption fileOptions[] = {
